@@ -16,7 +16,6 @@ __date__ ="Sep 23, 2011"
 
 import math
 import numpy as np
-import scipy.interpolate as spint
 import pymatgen.command_line.aconvasp_caller
 
 class _SpinImpl(object):
@@ -161,11 +160,12 @@ class Dos(object):
         """
         if not (self.energies == other.energies).all():
             raise ValueError("Energies of both DOS are not compatible!")
-        densities = {spin: self._dos[spin] + other._dos[spin] for spin in self.densities.keys()}
+        densities = {spin: self._dos[spin] + other._dos[spin] for spin in self._dos.keys()}
         return Dos(self.efermi, self.energies, densities)
 
     def get_interpolated_value(self,energy):
         f = {}
+        import scipy.interpolate as spint
         for spin in self._dos.keys():
             f[spin] = spint.interp1d(self._energies, self._dos[spin])(energy)
         return f
@@ -197,7 +197,7 @@ class Dos(object):
         above_fermi = [i for i in xrange(len(energies)) if energies[i] > self._efermi and tdos[i] > tol]
         vbm_start = max(below_fermi)
         cbm_start = min(above_fermi)
-        
+        import scipy.interpolate as spint
         if vbm_start == cbm_start:
             return 0.0,  self._efermi,self._efermi
         else:
@@ -280,7 +280,15 @@ class Dos(object):
             stringarray = ["#%30s %30s" %('Energy','DensityUp')]
             stringarray.extend(["%.5f %.5f" % (self._energies[i], self._dos[Spin.up][i]) for i in range(len(self._energies))])
         return "\n".join(stringarray)
-
+    
+    def to_dict(self):
+        d = {}
+        d['efermi'] = self._efermi
+        d['energies'] = list(self._energies)
+        d['densities'] = { str(int(spin)) : list(dens) for spin , dens in self._dos.items() }
+        return d
+        
+        
 class PDos(Dos):
     """
     Projected DOS for a specific orbital. Extends the Dos object.
@@ -312,7 +320,7 @@ class CompleteDos(Dos):
         self._efermi = total_dos.efermi
         self._energies = total_dos.energies
         self._dos = total_dos.densities
-        self._pdos = {structure[i]:{Orbital.from_vasp_index(j) : pdoss[i][j] for j in range(len(pdoss[i]))} for i in range(structure.num_sites)}
+        self._pdos = {structure[i]:{Orbital.from_vasp_index(j) : pdoss[i][j] for j in range(len(pdoss[i]))} for i in range(len(pdoss))}
         self._structure = structure
 
     @property
@@ -361,11 +369,30 @@ class CompleteDos(Dos):
             el = site.specie
             for pdos in atom_dos.values():
                 if el not in el_dos:
-                    el_dos[el] = Dos(pdos.efermi, pdos.energies,pdos.densities)
+                    el_dos[el] = Dos(pdos.efermi, pdos.energies, pdos.densities)
                 else:
                     el_dos[el] += pdos
         return el_dos
     
+    def to_dict(self, inc_all_pdos = True):
+        d = {}
+        d['efermi'] = self._efermi
+        d['structure'] = self._structure.to_dict
+        d['energies'] = list(self._energies)
+        d['densities'] = { str(int(spin)) : list(dens) for spin , dens in self._dos.items() }
+        if inc_all_pdos:
+            d['pdos'] = []
+            pdos = self._pdos
+            for i in range(len(pdos)):
+                dd = dict()
+                for dos in pdos[i]:
+                    dd[str(dos.orbital)] = {'efermi' : dos.efermi, 'energies': list(dos.energies), 'densities' : { str(int(spin)) : list(dens) for spin , dens in dos.densities.items() }}
+                d['pdos'].append(dd)
+        if len(self._pdos) > 0:
+            d['atom_dos'] = {str(at) : dos.to_dict() for at, dos in self.get_element_dos().items()}
+            d['spd_dos'] = {str(orb) : dos.to_dict() for orb, dos in self.get_spd_dos().items()}
+        return d
+    
     def __str__(self):
         return "Complete DOS for "+str(self._structure)
     
